window.Gleam.initSearch([{"doc":"glace","title":"glace","content":"# glace\n\n[![Package Version](https://img.shields.io/hexpm/v/glace)](https://hex.pm/packages/glace)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glace/)\n\n**Note: This is still early in the project and not ready for production use**\n\nA framework to build APIs quickly that focuses primarily on:\n1. Ease of use\n2. Fast to code\n3. Performance\n\n... in that order but it&#39;s still pretty fast, like really, really fast.\n\n### Installing\n\n`gleam add glace`\n\n### Usage\n\n```gleam\nimport glace\n\npub fn main() {\n\n  glace.new()\n  |&gt; glace.port(3000) // Skipping this will default to port 4000\n  |&gt; glace.get(&quot;/&quot;, fn(_) { glace.html(&quot;Hello, World!&quot;, status: 200) })\n  |&gt; glace.get(&quot;/text&quot;, fn(_) { glace.text(&quot;A text response&quot;, status: 200) })\n  |&gt; glace.get(&quot;/json&quot;, fn(_) { glace.json_string(&quot;{\\&quot;data\\&quot;: \\&quot;hello\\&quot;}&quot;, status: 200) })\n  |&gt; glace.get(&quot;/404&quot;, fn(_) { glace.not_found() })\n  |&gt; glace.start()\n  \n}\n```\n","url":"index.html"},{"doc":"glace","title":"Request","content":"pub type Request(context) =\n  glace_types.Request(context)\n A glace request that&#39;s a wrapper over gleam/http/request\n\nSynonyms:\nglace.Request\nglace Request","url":"glace.html#Request"},{"doc":"glace","title":"Response","content":"pub type Response =\n  response.Response(mist.ResponseData)\n A glace response that&#39;s a wrapper over gleam/http/response and mist.ResponseData\n\nSynonyms:\nglace.Response\nglace Response","url":"glace.html#Response"},{"doc":"glace","title":"configure_logger","content":"pub fn configure_logger(\n  builder: GlaceBuilder(a),\n  info info: fn(String) -&gt; Nil,\n  debug debug: fn(String) -&gt; Nil,\n  warn warn: fn(String) -&gt; Nil,\n  error error: fn(String) -&gt; Nil,\n) -&gt; GlaceBuilder(a)\n Configures a custom logger and overrides the default logger\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.configure_logger(info, debug, warn, error)\n |&gt; glace.get(&quot;/&quot;, fn(req) { handle_request(req) })\n |&gt; glace.start()\n \n fn info(message: String) {\n   io.println(&quot;Info: &quot; &lt;&gt; message) // This can write to any other destination using any logging library\n   Nil\n }\n \n fn debug(message: String) {\n   io.println(&quot;Debug: &quot; &lt;&gt; message)\n   Nil\n }\n \n fn warn(message: String) {\n   io.println(&quot;Warning: &quot; &lt;&gt; message)\n   Nil\n }\n \n fn error(message: String) {\n   io.println(&quot;Error: &quot; &lt;&gt; message)\n   Nil\n }\n \n fn handle_request(req: Request) -&gt; Response {\n   req.logger.info(&quot;Received request: &quot; &lt;&gt; req.path)\n   c.text(&quot;Connected to db&quot;, 200)\n }\n  \n \nSynonyms:\nglace.configure_logger\nglace configure_logger","url":"glace.html#configure_logger"},{"doc":"glace","title":"get","content":"pub fn get(\n  builder: GlaceBuilder(a),\n  path: String,\n  handler: fn(Request(a)) -&gt; Response(ResponseData),\n) -&gt; GlaceBuilder(a)\n Registers a GET request for the specified path\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(_) { glace.text(&quot;Hello, World!&quot;) })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.get\nglace get","url":"glace.html#get"},{"doc":"glace","title":"html","content":"pub fn html(\n  body input: String,\n  status status: Int,\n) -&gt; Response(ResponseData)\n Helper function to return html response for a request\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(_) { glace.html(&quot;Hello, World!&quot;) })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.html\nglace html","url":"glace.html#html"},{"doc":"glace","title":"json_string","content":"pub fn json_string(\n  body input: String,\n  status status: Int,\n) -&gt; Response(ResponseData)\n Helper function to return json response for a request\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(_) { glace.json_string(&quot;{\\&quot;hello\\&quot;: \\&quot;world\\&quot;}&quot;) })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.json_string\nglace json_string","url":"glace.html#json_string"},{"doc":"glace","title":"new","content":"pub fn new() -&gt; GlaceBuilder(a)\n Creates a new glace builder that allows chaining subsequent functions\n \n This is the entry point to setting `glace`\n \n Usage:\n\n \n \n glace.new()\n \n \nSynonyms:\nglace.new\nglace new","url":"glace.html#new"},{"doc":"glace","title":"not_found","content":"pub fn not_found() -&gt; Response(ResponseData)\n Helper function to return a `404` response for a request\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(_) { glace.not_found() })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.not_found\nglace not_found","url":"glace.html#not_found"},{"doc":"glace","title":"port","content":"pub fn port(\n  builder: GlaceBuilder(a),\n  port: Int,\n) -&gt; GlaceBuilder(a)\n Sets the port\n \n By default, glace starts listening on port 4000\n \n Using this function overrides the default port\n \n Usage:\n \n \n glace.new\n |&gt; glace.port(3000)\n \nSynonyms:\nglace.port\nglace port","url":"glace.html#port"},{"doc":"glace","title":"post","content":"pub fn post(\n  builder: GlaceBuilder(a),\n  path: String,\n  handler: fn(Request(a)) -&gt; Response(ResponseData),\n) -&gt; GlaceBuilder(a)\n Registers a POST request for the specified path\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.post(&quot;/&quot;, fn(_) { glace.text(&quot;Hello, World!&quot;) })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.post\nglace post","url":"glace.html#post"},{"doc":"glace","title":"start","content":"pub fn start(builder: GlaceBuilder(Nil)) -&gt; Subject(Message)\n Starts the server\n \n This is usually the last step in the pipeline\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(_) { glace.text(&quot;Hello, World!&quot;) })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.start\nglace start","url":"glace.html#start"},{"doc":"glace","title":"start_with_context","content":"pub fn start_with_context(\n  builder: GlaceBuilder(a),\n  context: a,\n) -&gt; Subject(Message)\n Starts the server with a context that will be forwarded for each request\n \n This is usually the last step in the pipeline (same as `start()` but with `context`)\n \n Usage:\n \n \n let context = Context(db: &quot;app.db&quot;)\n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(req) { handle_request(req) })\n |&gt; glace.start_with_context(context)\n \n fn handle_request(req: Request) -&gt; Response {\n   let db = request.context.db\n   c.text(&quot;Connected to db&quot;, 200)\n }\n \nSynonyms:\nglace.start_with_context\nglace start_with_context","url":"glace.html#start_with_context"},{"doc":"glace","title":"text","content":"pub fn text(\n  body input: String,\n  status status: Int,\n) -&gt; Response(ResponseData)\n Helper function to return text response for a request\n \n Usage:\n \n \n \n glace.new()\n |&gt; glace.get(&quot;/&quot;, fn(_) { glace.text(&quot;Hello, World!&quot;) })\n |&gt; glace.start()\n \n \nSynonyms:\nglace.text\nglace text","url":"glace.html#text"},{"doc":"glace","title":"glace","content":"","url":"glace.html"}]);